@@ -36,7 +36,7 @@ p.stars(
     style__marker__symbol="star_4",
 )
 
-p.messier(where=[_.magnitude < 11], true_size=False, label_fn=lambda d: f"M{d.m}")
+p.messier(where=[_.magnitude < 11], true_size=False)
 
 p.constellation_labels()
 p.horizon(labels={180: "SOUTH"})
