@@ -3,7 +3,7 @@ from zoneinfo import ZoneInfo
 
 from starplot import OpticPlot, DSO, Observer, _
 from starplot.callables import color_by_bv
-from starplot.optics import Refractor
+from starplot.models import Refractor
 from starplot.styles import PlotStyle, extensions
 
 dt = datetime(2023, 12, 16, 21, 0, 0, tzinfo=ZoneInfo("US/Pacific"))
