@@ -1,8 +1,14 @@
 import hashlib
 import imagehash
+
+from pathlib import Path
+
 from PIL import Image
 
 
+TEST_DATA_PATH = Path(__file__).resolve().parent / "data"
+
+
 def assert_hashes_equal(filename_1, filename_2):
     """Use two hash algorithms to assert files are equal"""
     assert_imagehash_equal(filename_1, filename_2)
